/**
 * Track crossing horizontal grid lines and if they are from above-to-below or below-to-above.
 * Similarly, track crossing vertical grid lines and if they are from left-to-right or right-to-left.
 * Partition such that one list includes left-to-right and bottom-to-top and the other includes
 * top-to-bottom and right-to-left.
 *
 * To see why this works, think of maintaining two "potential" counts. One for vertical and one
 * for horizontal with the values initialised to (0, 0). Each time you cross a horizontal line
 * bottom-to-top, increase the vertical potential. If you cross top-to-bottom, decrease the
 * vertical potential. If you cross a vertical grid line left-to-right, increase the horizontal
 * potential. If you cross a vertical grid line right-to-left, decrease the horizontal potential.
 * After traversing all edges, the counts will cancel out to zero. Since a value is added to
 * a partition every time that the potential counts change, we will get a partition with partite
 * lists of equal sum.
 *
 * Since the coordinates are in the range -K,K=(-1000,1000) and there are at most N=1000 points
 * each polygon edge can cross at most 2K horizontal grid lines and at most 2K vertical grid lines.
 * This gives time complexity O(4NK)
 *
 * @author Finn Lidbetter
 */


import kotlin.math.*

fun main() {
    val n = readLine()!!.toInt()
    var pts = Array<Pair<Double,Double>>(n) {
        val coordinates = readLine()!!.split(" ").map { it -> it.toDouble() }
        Pair(coordinates[0], coordinates[1])
    }
    var partition = ArrayList<Int>()
    for (i in 0..(n-1)) {
        val j = (i + 1) % n
        val p1x = pts[i].first
        val p1y = pts[i].second
        val p2x = pts[j].first
        val p2y = pts[j].second
        val horizontalDir = if ((p2x - p1x) > 0) 1 else -1
        val verticalDir = if ((p2y - p1y) > 0) 1 else -1

        val xMin = min(p1x, p2x)
        val xMax = max(p1x, p2x)
        for (x in ceil(xMin).toInt()..floor(xMax).toInt()) {
            val fraction = (x - p1x) / (p2x - p1x)
            val y = p1y + fraction * (p2y - p1y)
            val term = floor(y).toInt()
            if (horizontalDir == 1) {
                partition.add(term)
            }
        }
        val yMin = min(p1y, p2y)
        val yMax = max(p1y, p2y)
        for (y in ceil(yMin).toInt()..floor(yMax).toInt()) {
            val fraction  = (y - p1y) / (p2y - p1y)
            val x = p1x + fraction * (p2x - p1x)
            val term = floor(x).toInt()
            if (verticalDir == 1) {
                partition.add(term)
            }
        }
    }
    println(partition.size)
    for (term in partition) {
        println(term)
    }
}